MjHeadChild

Enum MjHeadChild 

pub enum MjHeadChild {
    Comment(Comment),
    MjAttributes(MjAttributes),
    MjBreakpoint(MjBreakpoint),
    MjFont(MjFont),
    MjInclude(MjIncludeHead),
    MjPreview(MjPreview),
    MjRaw(MjRaw),
    MjStyle(MjStyle),
    MjTitle(MjTitle),
}

Variants



Comment(Comment)



MjAttributes(MjAttributes)



MjBreakpoint(MjBreakpoint)



MjFont(MjFont)



MjInclude(MjIncludeHead)



MjPreview(MjPreview)



MjRaw(MjRaw)



MjStyle(MjStyle)



MjTitle(MjTitle)

Implementations

Source

impl MjHeadChild

pub fn is_comment(&self) -> bool

Returns true if this is a MjHeadChild::Comment, otherwise false

pub fn as_comment_mut(&mut self) -> Option<&mut Comment>

Optionally returns mutable references to the inner fields if this is a MjHeadChild::Comment, otherwise None

pub fn as_comment(&self) -> Option<&Comment>

Optionally returns references to the inner fields if this is a MjHeadChild::Comment, otherwise None

pub fn into_comment(self) -> Result<Comment, Self>

Returns the inner fields if this is a MjHeadChild::Comment, otherwise returns back the enum in the Err case of the result

pub fn is_mj_attributes(&self) -> bool

Returns true if this is a MjHeadChild::MjAttributes, otherwise false

pub fn as_mj_attributes_mut(&mut self) -> Option<&mut MjAttributes>

Optionally returns mutable references to the inner fields if this is a MjHeadChild::MjAttributes, otherwise None

pub fn as_mj_attributes(&self) -> Option<&MjAttributes>

Optionally returns references to the inner fields if this is a MjHeadChild::MjAttributes, otherwise None

pub fn into_mj_attributes(self) -> Result<MjAttributes, Self>

Returns the inner fields if this is a MjHeadChild::MjAttributes, otherwise returns back the enum in the Err case of the result

pub fn is_mj_breakpoint(&self) -> bool

Returns true if this is a MjHeadChild::MjBreakpoint, otherwise false

pub fn as_mj_breakpoint_mut(&mut self) -> Option<&mut MjBreakpoint>

Optionally returns mutable references to the inner fields if this is a MjHeadChild::MjBreakpoint, otherwise None

pub fn as_mj_breakpoint(&self) -> Option<&MjBreakpoint>

Optionally returns references to the inner fields if this is a MjHeadChild::MjBreakpoint, otherwise None

pub fn into_mj_breakpoint(self) -> Result<MjBreakpoint, Self>

Returns the inner fields if this is a MjHeadChild::MjBreakpoint, otherwise returns back the enum in the Err case of the result

pub fn is_mj_font(&self) -> bool

Returns true if this is a MjHeadChild::MjFont, otherwise false

pub fn as_mj_font_mut(&mut self) -> Option<&mut MjFont>

Optionally returns mutable references to the inner fields if this is a MjHeadChild::MjFont, otherwise None

pub fn as_mj_font(&self) -> Option<&MjFont>

Optionally returns references to the inner fields if this is a MjHeadChild::MjFont, otherwise None

pub fn into_mj_font(self) -> Result<MjFont, Self>

Returns the inner fields if this is a MjHeadChild::MjFont, otherwise returns back the enum in the Err case of the result

pub fn is_mj_include(&self) -> bool

Returns true if this is a MjHeadChild::MjInclude, otherwise false

pub fn as_mj_include_mut(&mut self) -> Option<&mut MjIncludeHead>

Optionally returns mutable references to the inner fields if this is a MjHeadChild::MjInclude, otherwise None

pub fn as_mj_include(&self) -> Option<&MjIncludeHead>

Optionally returns references to the inner fields if this is a MjHeadChild::MjInclude, otherwise None

pub fn into_mj_include(self) -> Result<MjIncludeHead, Self>

Returns the inner fields if this is a MjHeadChild::MjInclude, otherwise returns back the enum in the Err case of the result

pub fn is_mj_preview(&self) -> bool

Returns true if this is a MjHeadChild::MjPreview, otherwise false

pub fn as_mj_preview_mut(&mut self) -> Option<&mut MjPreview>

Optionally returns mutable references to the inner fields if this is a MjHeadChild::MjPreview, otherwise None

pub fn as_mj_preview(&self) -> Option<&MjPreview>

Optionally returns references to the inner fields if this is a MjHeadChild::MjPreview, otherwise None

pub fn into_mj_preview(self) -> Result<MjPreview, Self>

Returns the inner fields if this is a MjHeadChild::MjPreview, otherwise returns back the enum in the Err case of the result

pub fn is_mj_raw(&self) -> bool

Returns true if this is a MjHeadChild::MjRaw, otherwise false

pub fn as_mj_raw_mut(&mut self) -> Option<&mut MjRaw>

Optionally returns mutable references to the inner fields if this is a MjHeadChild::MjRaw, otherwise None

pub fn as_mj_raw(&self) -> Option<&MjRaw>

Optionally returns references to the inner fields if this is a MjHeadChild::MjRaw, otherwise None

pub fn into_mj_raw(self) -> Result<MjRaw, Self>

Returns the inner fields if this is a MjHeadChild::MjRaw, otherwise returns back the enum in the Err case of the result

pub fn is_mj_style(&self) -> bool

Returns true if this is a MjHeadChild::MjStyle, otherwise false

pub fn as_mj_style_mut(&mut self) -> Option<&mut MjStyle>

Optionally returns mutable references to the inner fields if this is a MjHeadChild::MjStyle, otherwise None

pub fn as_mj_style(&self) -> Option<&MjStyle>

Optionally returns references to the inner fields if this is a MjHeadChild::MjStyle, otherwise None

pub fn into_mj_style(self) -> Result<MjStyle, Self>

Returns the inner fields if this is a MjHeadChild::MjStyle, otherwise returns back the enum in the Err case of the result

pub fn is_mj_title(&self) -> bool

Returns true if this is a MjHeadChild::MjTitle, otherwise false

pub fn as_mj_title_mut(&mut self) -> Option<&mut MjTitle>

Optionally returns mutable references to the inner fields if this is a MjHeadChild::MjTitle, otherwise None

pub fn as_mj_title(&self) -> Option<&MjTitle>

Optionally returns references to the inner fields if this is a MjHeadChild::MjTitle, otherwise None

pub fn into_mj_title(self) -> Result<MjTitle, Self>

Returns the inner fields if this is a MjHeadChild::MjTitle, otherwise returns back the enum in the Err case of the result