MjIncludeHeadChild

Enum MjIncludeHeadChild 

pub enum MjIncludeHeadChild {
    Comment(Comment),
    MjAttributes(MjAttributes),
    MjBreakpoint(MjBreakpoint),
    MjFont(MjFont),
    MjPreview(MjPreview),
    MjRaw(MjRaw),
    MjStyle(MjStyle),
    MjTitle(MjTitle),
    Text(Text),
}

Variants



Comment(Comment)



MjAttributes(MjAttributes)



MjBreakpoint(MjBreakpoint)



MjFont(MjFont)



MjPreview(MjPreview)



MjRaw(MjRaw)



MjStyle(MjStyle)



MjTitle(MjTitle)



Text(Text)

Implementations

Source

impl MjIncludeHeadChild

pub fn is_comment(&self) -> bool

Returns true if this is a MjIncludeHeadChild::Comment, otherwise false

pub fn as_comment_mut(&mut self) -> Option<&mut Comment>

Optionally returns mutable references to the inner fields if this is a MjIncludeHeadChild::Comment, otherwise None

pub fn as_comment(&self) -> Option<&Comment>

Optionally returns references to the inner fields if this is a MjIncludeHeadChild::Comment, otherwise None

pub fn into_comment(self) -> Result<Comment, Self>

Returns the inner fields if this is a MjIncludeHeadChild::Comment, otherwise returns back the enum in the Err case of the result

pub fn is_mj_attributes(&self) -> bool

Returns true if this is a MjIncludeHeadChild::MjAttributes, otherwise false

pub fn as_mj_attributes_mut(&mut self) -> Option<&mut MjAttributes>

Optionally returns mutable references to the inner fields if this is a MjIncludeHeadChild::MjAttributes, otherwise None

pub fn as_mj_attributes(&self) -> Option<&MjAttributes>

Optionally returns references to the inner fields if this is a MjIncludeHeadChild::MjAttributes, otherwise None

pub fn into_mj_attributes(self) -> Result<MjAttributes, Self>

Returns the inner fields if this is a MjIncludeHeadChild::MjAttributes, otherwise returns back the enum in the Err case of the result

pub fn is_mj_breakpoint(&self) -> bool

Returns true if this is a MjIncludeHeadChild::MjBreakpoint, otherwise false

pub fn as_mj_breakpoint_mut(&mut self) -> Option<&mut MjBreakpoint>

Optionally returns mutable references to the inner fields if this is a MjIncludeHeadChild::MjBreakpoint, otherwise None

pub fn as_mj_breakpoint(&self) -> Option<&MjBreakpoint>

Optionally returns references to the inner fields if this is a MjIncludeHeadChild::MjBreakpoint, otherwise None

pub fn into_mj_breakpoint(self) -> Result<MjBreakpoint, Self>

Returns the inner fields if this is a MjIncludeHeadChild::MjBreakpoint, otherwise returns back the enum in the Err case of the result

pub fn is_mj_font(&self) -> bool

Returns true if this is a MjIncludeHeadChild::MjFont, otherwise false

pub fn as_mj_font_mut(&mut self) -> Option<&mut MjFont>

Optionally returns mutable references to the inner fields if this is a MjIncludeHeadChild::MjFont, otherwise None

pub fn as_mj_font(&self) -> Option<&MjFont>

Optionally returns references to the inner fields if this is a MjIncludeHeadChild::MjFont, otherwise None

pub fn into_mj_font(self) -> Result<MjFont, Self>

Returns the inner fields if this is a MjIncludeHeadChild::MjFont, otherwise returns back the enum in the Err case of the result

pub fn is_mj_preview(&self) -> bool

Returns true if this is a MjIncludeHeadChild::MjPreview, otherwise false

pub fn as_mj_preview_mut(&mut self) -> Option<&mut MjPreview>

Optionally returns mutable references to the inner fields if this is a MjIncludeHeadChild::MjPreview, otherwise None

pub fn as_mj_preview(&self) -> Option<&MjPreview>

Optionally returns references to the inner fields if this is a MjIncludeHeadChild::MjPreview, otherwise None

pub fn into_mj_preview(self) -> Result<MjPreview, Self>

Returns the inner fields if this is a MjIncludeHeadChild::MjPreview, otherwise returns back the enum in the Err case of the result

pub fn is_mj_raw(&self) -> bool

Returns true if this is a MjIncludeHeadChild::MjRaw, otherwise false

pub fn as_mj_raw_mut(&mut self) -> Option<&mut MjRaw>

Optionally returns mutable references to the inner fields if this is a MjIncludeHeadChild::MjRaw, otherwise None

pub fn as_mj_raw(&self) -> Option<&MjRaw>

Optionally returns references to the inner fields if this is a MjIncludeHeadChild::MjRaw, otherwise None

pub fn into_mj_raw(self) -> Result<MjRaw, Self>

Returns the inner fields if this is a MjIncludeHeadChild::MjRaw, otherwise returns back the enum in the Err case of the result

pub fn is_mj_style(&self) -> bool

Returns true if this is a MjIncludeHeadChild::MjStyle, otherwise false

pub fn as_mj_style_mut(&mut self) -> Option<&mut MjStyle>

Optionally returns mutable references to the inner fields if this is a MjIncludeHeadChild::MjStyle, otherwise None

pub fn as_mj_style(&self) -> Option<&MjStyle>

Optionally returns references to the inner fields if this is a MjIncludeHeadChild::MjStyle, otherwise None

pub fn into_mj_style(self) -> Result<MjStyle, Self>

Returns the inner fields if this is a MjIncludeHeadChild::MjStyle, otherwise returns back the enum in the Err case of the result

pub fn is_mj_title(&self) -> bool

Returns true if this is a MjIncludeHeadChild::MjTitle, otherwise false

pub fn as_mj_title_mut(&mut self) -> Option<&mut MjTitle>

Optionally returns mutable references to the inner fields if this is a MjIncludeHeadChild::MjTitle, otherwise None

pub fn as_mj_title(&self) -> Option<&MjTitle>

Optionally returns references to the inner fields if this is a MjIncludeHeadChild::MjTitle, otherwise None

pub fn into_mj_title(self) -> Result<MjTitle, Self>

Returns the inner fields if this is a MjIncludeHeadChild::MjTitle, otherwise returns back the enum in the Err case of the result

pub fn is_text(&self) -> bool

Returns true if this is a MjIncludeHeadChild::Text, otherwise false

pub fn as_text_mut(&mut self) -> Option<&mut Text>

Optionally returns mutable references to the inner fields if this is a MjIncludeHeadChild::Text, otherwise None

pub fn as_text(&self) -> Option<&Text>

Optionally returns references to the inner fields if this is a MjIncludeHeadChild::Text, otherwise None

pub fn into_text(self) -> Result<Text, Self>

Returns the inner fields if this is a MjIncludeHeadChild::Text, otherwise returns back the enum in the Err case of the result