Component

Struct Component 

pub struct Component<Tag, Attributes, Children> {
    pub tag: Tag,
    pub attributes: Attributes,
    pub children: Children,
}

Fields

tag: Tagattributes: Attributeschildren: Children

Implementations

Source

impl Component<PhantomData<MjAttributesTag>, (), Vec<MjAttributesChild>>

Source

impl Component<PhantomData<MjAttributesAllTag>, Map<String, Option<String>>, ()>

pub fn attributes(&self) -> &AttributeMap

Source

impl Component<PhantomData<MjBreakpointTag>, MjBreakpointAttributes, ()>

pub fn value(&self) -> &str

Source

impl Component<PhantomData<MjFontTag>, MjFontAttributes, ()>

pub fn name(&self) -> &str

pub fn href(&self) -> &str

Source

impl Component<PhantomData<MjHeadTag>, (), Vec<MjHeadChild>>

pub fn build_attributes_all(&self) -> Map<&str, &str>

pub fn build_attributes_class(&self) -> Map<&str, Map<&str, &str>>

pub fn build_attributes_element(&self) -> Map<&str, Map<&str, &str>>

pub fn build_font_families(&self) -> Map<&str, &str>

Source

impl Component<PhantomData<MjHeadTag>, (), Vec<MjHeadChild>>

pub fn breakpoint(&self) -> Option<&MjBreakpoint>

pub fn preview(&self) -> Option<&MjPreview>

pub fn title(&self) -> Option<&MjTitle>

pub fn children(&self) -> &Vec<MjHeadChild>

Source

impl Component<PhantomData<MjPreviewTag>, (), OneOrMany<MjPreviewChild>>

pub fn content(&self) -> String

Source

impl Component<PhantomData<MjStyleTag>, MjStyleAttributes, String>

pub fn is_inline(&self) -> bool

pub fn children(&self) -> &str

Source

impl Component<PhantomData<MjTitleTag>, (), String>

pub fn content(&self) -> &str

Source

impl Component<PhantomData<MjmlTag>, MjmlAttributes, MjmlChildren>

pub fn parse_with_options<T: AsRef<str>>( value: T, opts: &ParserOptions, ) -> Result<ParseOutput<Self>, Error>

Function to parse a raw mjml template with some parsing options.

You can specify the kind of loader mrml needs to use for loading the content of mj-include elements.

You can take a look at the available loaders here.

use mrml::mjml::Mjml;
use mrml::prelude::parser::ParserOptions;
use mrml::prelude::parser::memory_loader::MemoryIncludeLoader;

let options = ParserOptions {
    include_loader: Box::new(MemoryIncludeLoader::default()),
};
match Mjml::parse_with_options("<mjml><mj-head /><mj-body /></mjml>", &options) {
    Ok(_) => println!("Success!"),
    Err(err) => eprintln!("Something went wrong: {err:?}"),
}
pub fn parse<T: AsRef<str>>(value: T) -> Result<ParseOutput<Self>, Error>

Function to parse a raw mjml template using the default parsing options.

Source

impl Component<PhantomData<MjmlTag>, MjmlAttributes, MjmlChildren>

pub fn render(&self, opts: &RenderOptions) -> Result<String, Error>

pub fn get_title(&self) -> Option<String>

pub fn get_preview(&self) -> Option<String>

Source

impl Component<PhantomData<MjmlTag>, MjmlAttributes, MjmlChildren>

pub fn body(&self) -> Option<&MjBody>

pub fn head(&self) -> Option<&MjHead>

Source

impl<T, A, C> Component<PhantomData<T>, A, C>

pub fn new(attributes: A, children: C) -> Self