pub enum MjIncludeHeadChild {
Comment(Comment),
MjAttributes(MjAttributes),
MjBreakpoint(MjBreakpoint),
MjFont(MjFont),
MjPreview(MjPreview),
MjRaw(MjRaw),
MjStyle(MjStyle),
MjTitle(MjTitle),
Text(Text),
}Variants
Comment(Comment)
MjAttributes(MjAttributes)
MjBreakpoint(MjBreakpoint)
MjFont(MjFont)
MjPreview(MjPreview)
MjRaw(MjRaw)
MjStyle(MjStyle)
MjTitle(MjTitle)
Text(Text)
Implementations
Sourceimpl MjIncludeHeadChild
impl MjIncludeHeadChild
Sourcepub fn is_comment(&self) -> bool
pub fn is_comment(&self) -> bool
Returns true if this is a MjIncludeHeadChild::Comment, otherwise false
Sourcepub fn as_comment_mut(&mut self) -> Option<&mut Comment>
pub fn as_comment_mut(&mut self) -> Option<&mut Comment>
Optionally returns mutable references to the inner fields if this is a MjIncludeHeadChild::Comment, otherwise None
Sourcepub fn as_comment(&self) -> Option<&Comment>
pub fn as_comment(&self) -> Option<&Comment>
Optionally returns references to the inner fields if this is a MjIncludeHeadChild::Comment, otherwise None
Sourcepub fn into_comment(self) -> Result<Comment, Self>
pub fn into_comment(self) -> Result<Comment, Self>
Returns the inner fields if this is a MjIncludeHeadChild::Comment, otherwise returns back the enum in the Err case of the result
Sourcepub fn is_mj_attributes(&self) -> bool
pub fn is_mj_attributes(&self) -> bool
Returns true if this is a MjIncludeHeadChild::MjAttributes, otherwise false
Sourcepub fn as_mj_attributes_mut(&mut self) -> Option<&mut MjAttributes>
pub fn as_mj_attributes_mut(&mut self) -> Option<&mut MjAttributes>
Optionally returns mutable references to the inner fields if this is a MjIncludeHeadChild::MjAttributes, otherwise None
Sourcepub fn as_mj_attributes(&self) -> Option<&MjAttributes>
pub fn as_mj_attributes(&self) -> Option<&MjAttributes>
Optionally returns references to the inner fields if this is a MjIncludeHeadChild::MjAttributes, otherwise None
Sourcepub fn into_mj_attributes(self) -> Result<MjAttributes, Self>
pub fn into_mj_attributes(self) -> Result<MjAttributes, Self>
Returns the inner fields if this is a MjIncludeHeadChild::MjAttributes, otherwise returns back the enum in the Err case of the result
Sourcepub fn is_mj_breakpoint(&self) -> bool
pub fn is_mj_breakpoint(&self) -> bool
Returns true if this is a MjIncludeHeadChild::MjBreakpoint, otherwise false
Sourcepub fn as_mj_breakpoint_mut(&mut self) -> Option<&mut MjBreakpoint>
pub fn as_mj_breakpoint_mut(&mut self) -> Option<&mut MjBreakpoint>
Optionally returns mutable references to the inner fields if this is a MjIncludeHeadChild::MjBreakpoint, otherwise None
Sourcepub fn as_mj_breakpoint(&self) -> Option<&MjBreakpoint>
pub fn as_mj_breakpoint(&self) -> Option<&MjBreakpoint>
Optionally returns references to the inner fields if this is a MjIncludeHeadChild::MjBreakpoint, otherwise None
Sourcepub fn into_mj_breakpoint(self) -> Result<MjBreakpoint, Self>
pub fn into_mj_breakpoint(self) -> Result<MjBreakpoint, Self>
Returns the inner fields if this is a MjIncludeHeadChild::MjBreakpoint, otherwise returns back the enum in the Err case of the result
Sourcepub fn is_mj_font(&self) -> bool
pub fn is_mj_font(&self) -> bool
Returns true if this is a MjIncludeHeadChild::MjFont, otherwise false
Sourcepub fn as_mj_font_mut(&mut self) -> Option<&mut MjFont>
pub fn as_mj_font_mut(&mut self) -> Option<&mut MjFont>
Optionally returns mutable references to the inner fields if this is a MjIncludeHeadChild::MjFont, otherwise None
Sourcepub fn as_mj_font(&self) -> Option<&MjFont>
pub fn as_mj_font(&self) -> Option<&MjFont>
Optionally returns references to the inner fields if this is a MjIncludeHeadChild::MjFont, otherwise None
Sourcepub fn into_mj_font(self) -> Result<MjFont, Self>
pub fn into_mj_font(self) -> Result<MjFont, Self>
Returns the inner fields if this is a MjIncludeHeadChild::MjFont, otherwise returns back the enum in the Err case of the result
Sourcepub fn is_mj_preview(&self) -> bool
pub fn is_mj_preview(&self) -> bool
Returns true if this is a MjIncludeHeadChild::MjPreview, otherwise false
Sourcepub fn as_mj_preview_mut(&mut self) -> Option<&mut MjPreview>
pub fn as_mj_preview_mut(&mut self) -> Option<&mut MjPreview>
Optionally returns mutable references to the inner fields if this is a MjIncludeHeadChild::MjPreview, otherwise None
Sourcepub fn as_mj_preview(&self) -> Option<&MjPreview>
pub fn as_mj_preview(&self) -> Option<&MjPreview>
Optionally returns references to the inner fields if this is a MjIncludeHeadChild::MjPreview, otherwise None
Sourcepub fn into_mj_preview(self) -> Result<MjPreview, Self>
pub fn into_mj_preview(self) -> Result<MjPreview, Self>
Returns the inner fields if this is a MjIncludeHeadChild::MjPreview, otherwise returns back the enum in the Err case of the result
Sourcepub fn is_mj_raw(&self) -> bool
pub fn is_mj_raw(&self) -> bool
Returns true if this is a MjIncludeHeadChild::MjRaw, otherwise false
Sourcepub fn as_mj_raw_mut(&mut self) -> Option<&mut MjRaw>
pub fn as_mj_raw_mut(&mut self) -> Option<&mut MjRaw>
Optionally returns mutable references to the inner fields if this is a MjIncludeHeadChild::MjRaw, otherwise None
Sourcepub fn as_mj_raw(&self) -> Option<&MjRaw>
pub fn as_mj_raw(&self) -> Option<&MjRaw>
Optionally returns references to the inner fields if this is a MjIncludeHeadChild::MjRaw, otherwise None
Sourcepub fn into_mj_raw(self) -> Result<MjRaw, Self>
pub fn into_mj_raw(self) -> Result<MjRaw, Self>
Returns the inner fields if this is a MjIncludeHeadChild::MjRaw, otherwise returns back the enum in the Err case of the result
Sourcepub fn is_mj_style(&self) -> bool
pub fn is_mj_style(&self) -> bool
Returns true if this is a MjIncludeHeadChild::MjStyle, otherwise false
Sourcepub fn as_mj_style_mut(&mut self) -> Option<&mut MjStyle>
pub fn as_mj_style_mut(&mut self) -> Option<&mut MjStyle>
Optionally returns mutable references to the inner fields if this is a MjIncludeHeadChild::MjStyle, otherwise None
Sourcepub fn as_mj_style(&self) -> Option<&MjStyle>
pub fn as_mj_style(&self) -> Option<&MjStyle>
Optionally returns references to the inner fields if this is a MjIncludeHeadChild::MjStyle, otherwise None
Sourcepub fn into_mj_style(self) -> Result<MjStyle, Self>
pub fn into_mj_style(self) -> Result<MjStyle, Self>
Returns the inner fields if this is a MjIncludeHeadChild::MjStyle, otherwise returns back the enum in the Err case of the result
Sourcepub fn is_mj_title(&self) -> bool
pub fn is_mj_title(&self) -> bool
Returns true if this is a MjIncludeHeadChild::MjTitle, otherwise false
Sourcepub fn as_mj_title_mut(&mut self) -> Option<&mut MjTitle>
pub fn as_mj_title_mut(&mut self) -> Option<&mut MjTitle>
Optionally returns mutable references to the inner fields if this is a MjIncludeHeadChild::MjTitle, otherwise None
Sourcepub fn as_mj_title(&self) -> Option<&MjTitle>
pub fn as_mj_title(&self) -> Option<&MjTitle>
Optionally returns references to the inner fields if this is a MjIncludeHeadChild::MjTitle, otherwise None
Sourcepub fn into_mj_title(self) -> Result<MjTitle, Self>
pub fn into_mj_title(self) -> Result<MjTitle, Self>
Returns the inner fields if this is a MjIncludeHeadChild::MjTitle, otherwise returns back the enum in the Err case of the result
Sourcepub fn is_text(&self) -> bool
pub fn is_text(&self) -> bool
Returns true if this is a MjIncludeHeadChild::Text, otherwise false
Sourcepub fn as_text_mut(&mut self) -> Option<&mut Text>
pub fn as_text_mut(&mut self) -> Option<&mut Text>
Optionally returns mutable references to the inner fields if this is a MjIncludeHeadChild::Text, otherwise None