pub struct Component<Tag, Attributes, Children> {
pub tag: Tag,
pub attributes: Attributes,
pub children: Children,
}Fields
tag: Tagattributes: Attributeschildren: ChildrenImplementations
Sourceimpl Component<PhantomData<MjAttributesTag>, (), Vec<MjAttributesChild>>
impl Component<PhantomData<MjAttributesTag>, (), Vec<MjAttributesChild>>
pub fn children(&self) -> &Vec<MjAttributesChild>
Sourceimpl Component<PhantomData<MjAttributesAllTag>, Map<String, Option<String>>, ()>
impl Component<PhantomData<MjAttributesAllTag>, Map<String, Option<String>>, ()>
pub fn attributes(&self) -> &AttributeMap
Sourceimpl Component<PhantomData<MjHeadTag>, (), Vec<MjHeadChild>>
impl Component<PhantomData<MjHeadTag>, (), Vec<MjHeadChild>>
Sourceimpl Component<PhantomData<MjHeadTag>, (), Vec<MjHeadChild>>
impl Component<PhantomData<MjHeadTag>, (), Vec<MjHeadChild>>
Sourceimpl Component<PhantomData<MjTitleTag>, (), String>
impl Component<PhantomData<MjTitleTag>, (), String>
Sourceimpl Component<PhantomData<MjmlTag>, MjmlAttributes, MjmlChildren>
impl Component<PhantomData<MjmlTag>, MjmlAttributes, MjmlChildren>
Sourcepub fn parse_with_options<T: AsRef<str>>(
value: T,
opts: &ParserOptions,
) -> Result<ParseOutput<Self>, Error>
pub fn parse_with_options<T: AsRef<str>>( value: T, opts: &ParserOptions, ) -> Result<ParseOutput<Self>, Error>
Function to parse a raw mjml template with some parsing options.
You can specify the kind of loader mrml needs to use for loading the
content of mj-include elements.
You can take a look at the available loaders here.
use mrml::mjml::Mjml;
use mrml::prelude::parser::ParserOptions;
use mrml::prelude::parser::memory_loader::MemoryIncludeLoader;
let options = ParserOptions {
include_loader: Box::new(MemoryIncludeLoader::default()),
};
match Mjml::parse_with_options("<mjml><mj-head /><mj-body /></mjml>", &options) {
Ok(_) => println!("Success!"),
Err(err) => eprintln!("Something went wrong: {err:?}"),
}Trait Implementations
Sourceimpl<Tag: Clone, Attributes: Clone, Children: Clone> Clone for Component<Tag, Attributes, Children>
impl<Tag: Clone, Attributes: Clone, Children: Clone> Clone for Component<Tag, Attributes, Children>
Sourceimpl<Tag: Debug, Attributes: Debug, Children: Debug> Debug for Component<Tag, Attributes, Children>
impl<Tag: Debug, Attributes: Debug, Children: Debug> Debug for Component<Tag, Attributes, Children>
Sourceimpl<'de, Tag, Attributes, Children> Deserialize<'de> for Component<Tag, Attributes, Children>where
DeserializableTag<Tag>: Deserialize<'de>,
Attributes: JsonAttributes + Deserialize<'de>,
Children: JsonChildren + Deserialize<'de>,
impl<'de, Tag, Attributes, Children> Deserialize<'de> for Component<Tag, Attributes, Children>where
DeserializableTag<Tag>: Deserialize<'de>,
Attributes: JsonAttributes + Deserialize<'de>,
Children: JsonChildren + Deserialize<'de>,
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<Component<PhantomData<CommentTag>, (), String>> for MjAccordionChild
impl From<Component<PhantomData<CommentTag>, (), String>> for MjAccordionChild
Sourcefn from(v: Comment) -> MjAccordionChild
fn from(v: Comment) -> MjAccordionChild
Converts to this type from the input type.
Sourceimpl From<Component<PhantomData<CommentTag>, (), String>> for MjBodyChild
impl From<Component<PhantomData<CommentTag>, (), String>> for MjBodyChild
Sourcefn from(v: Comment) -> MjBodyChild
fn from(v: Comment) -> MjBodyChild
Converts to this type from the input type.
Sourceimpl From<Component<PhantomData<CommentTag>, (), String>> for MjCarouselChild
impl From<Component<PhantomData<CommentTag>, (), String>> for MjCarouselChild
Sourcefn from(v: Comment) -> MjCarouselChild
fn from(v: Comment) -> MjCarouselChild
Converts to this type from the input type.
Sourceimpl From<Component<PhantomData<CommentTag>, (), String>> for MjHeadChild
impl From<Component<PhantomData<CommentTag>, (), String>> for MjHeadChild
Sourcefn from(v: Comment) -> MjHeadChild
fn from(v: Comment) -> MjHeadChild
Converts to this type from the input type.
Sourcefn from(v: Comment) -> MjNavbarChild
fn from(v: Comment) -> MjNavbarChild
Converts to this type from the input type.
Sourceimpl From<Component<PhantomData<CommentTag>, (), String>> for MjRawChild
impl From<Component<PhantomData<CommentTag>, (), String>> for MjRawChild
Sourcefn from(v: Comment) -> MjRawChild
fn from(v: Comment) -> MjRawChild
Converts to this type from the input type.
Sourceimpl From<Component<PhantomData<CommentTag>, (), String>> for MjSocialChild
impl From<Component<PhantomData<CommentTag>, (), String>> for MjSocialChild
Sourcefn from(v: Comment) -> MjSocialChild
fn from(v: Comment) -> MjSocialChild
Converts to this type from the input type.
Sourceimpl From<Component<PhantomData<MjAccordionElementTag>, Map<String, Option<String>>, MjAccordionElementChildren>> for MjAccordionChild
impl From<Component<PhantomData<MjAccordionElementTag>, Map<String, Option<String>>, MjAccordionElementChildren>> for MjAccordionChild
Sourcefn from(v: MjAccordionElement) -> MjAccordionChild
fn from(v: MjAccordionElement) -> MjAccordionChild
Converts to this type from the input type.
Sourceimpl From<Component<PhantomData<MjAccordionTag>, Map<String, Option<String>>, Vec<MjAccordionChild>>> for MjBodyChild
impl From<Component<PhantomData<MjAccordionTag>, Map<String, Option<String>>, Vec<MjAccordionChild>>> for MjBodyChild
Sourcefn from(v: MjAccordion) -> MjBodyChild
fn from(v: MjAccordion) -> MjBodyChild
Converts to this type from the input type.
Sourceimpl From<Component<PhantomData<MjAttributesAllTag>, Map<String, Option<String>>, ()>> for MjAttributesChild
impl From<Component<PhantomData<MjAttributesAllTag>, Map<String, Option<String>>, ()>> for MjAttributesChild
Sourcefn from(v: MjAttributesAll) -> MjAttributesChild
fn from(v: MjAttributesAll) -> MjAttributesChild
Converts to this type from the input type.
Sourceimpl From<Component<PhantomData<MjAttributesClassTag>, MjAttributesClassAttributes, ()>> for MjAttributesChild
impl From<Component<PhantomData<MjAttributesClassTag>, MjAttributesClassAttributes, ()>> for MjAttributesChild
Sourcefn from(v: MjAttributesClass) -> MjAttributesChild
fn from(v: MjAttributesClass) -> MjAttributesChild
Converts to this type from the input type.
Sourceimpl From<Component<PhantomData<MjAttributesTag>, (), Vec<MjAttributesChild>>> for MjHeadChild
impl From<Component<PhantomData<MjAttributesTag>, (), Vec<MjAttributesChild>>> for MjHeadChild
Sourcefn from(v: MjAttributes) -> MjHeadChild
fn from(v: MjAttributes) -> MjHeadChild
Converts to this type from the input type.
Sourceimpl From<Component<PhantomData<MjBreakpointTag>, MjBreakpointAttributes, ()>> for MjHeadChild
impl From<Component<PhantomData<MjBreakpointTag>, MjBreakpointAttributes, ()>> for MjHeadChild
Sourcefn from(v: MjBreakpoint) -> MjHeadChild
fn from(v: MjBreakpoint) -> MjHeadChild
Converts to this type from the input type.
Sourceimpl From<Component<PhantomData<MjButtonTag>, Map<String, Option<String>>, Vec<MjBodyChild>>> for MjBodyChild
impl From<Component<PhantomData<MjButtonTag>, Map<String, Option<String>>, Vec<MjBodyChild>>> for MjBodyChild
Sourcefn from(v: MjButton) -> MjBodyChild
fn from(v: MjButton) -> MjBodyChild
Converts to this type from the input type.
Sourceimpl From<Component<PhantomData<MjCarouselImageTag>, Map<String, Option<String>>, ()>> for MjCarouselChild
impl From<Component<PhantomData<MjCarouselImageTag>, Map<String, Option<String>>, ()>> for MjCarouselChild
Sourcefn from(v: MjCarouselImage) -> MjCarouselChild
fn from(v: MjCarouselImage) -> MjCarouselChild
Converts to this type from the input type.
Sourceimpl From<Component<PhantomData<MjCarouselTag>, Map<String, Option<String>>, Vec<MjCarouselChild>>> for MjBodyChild
impl From<Component<PhantomData<MjCarouselTag>, Map<String, Option<String>>, Vec<MjCarouselChild>>> for MjBodyChild
Sourcefn from(v: MjCarousel) -> MjBodyChild
fn from(v: MjCarousel) -> MjBodyChild
Converts to this type from the input type.
Sourceimpl From<Component<PhantomData<MjColumnTag>, Map<String, Option<String>>, Vec<MjBodyChild>>> for MjBodyChild
impl From<Component<PhantomData<MjColumnTag>, Map<String, Option<String>>, Vec<MjBodyChild>>> for MjBodyChild
Sourcefn from(v: MjColumn) -> MjBodyChild
fn from(v: MjColumn) -> MjBodyChild
Converts to this type from the input type.
Sourceimpl From<Component<PhantomData<MjDividerTag>, Map<String, Option<String>>, ()>> for MjBodyChild
impl From<Component<PhantomData<MjDividerTag>, Map<String, Option<String>>, ()>> for MjBodyChild
Sourcefn from(v: MjDivider) -> MjBodyChild
fn from(v: MjDivider) -> MjBodyChild
Converts to this type from the input type.
Sourceimpl From<Component<PhantomData<MjFontTag>, MjFontAttributes, ()>> for MjHeadChild
impl From<Component<PhantomData<MjFontTag>, MjFontAttributes, ()>> for MjHeadChild
Sourcefn from(v: MjFont) -> MjHeadChild
fn from(v: MjFont) -> MjHeadChild
Converts to this type from the input type.
Sourceimpl From<Component<PhantomData<MjGroupTag>, Map<String, Option<String>>, Vec<MjBodyChild>>> for MjBodyChild
impl From<Component<PhantomData<MjGroupTag>, Map<String, Option<String>>, Vec<MjBodyChild>>> for MjBodyChild
Sourcefn from(v: MjGroup) -> MjBodyChild
fn from(v: MjGroup) -> MjBodyChild
Converts to this type from the input type.
Sourceimpl From<Component<PhantomData<MjHeroTag>, Map<String, Option<String>>, Vec<MjBodyChild>>> for MjBodyChild
impl From<Component<PhantomData<MjHeroTag>, Map<String, Option<String>>, Vec<MjBodyChild>>> for MjBodyChild
Sourcefn from(v: MjHero) -> MjBodyChild
fn from(v: MjHero) -> MjBodyChild
Converts to this type from the input type.
Sourceimpl From<Component<PhantomData<MjImageTag>, Map<String, Option<String>>, ()>> for MjBodyChild
impl From<Component<PhantomData<MjImageTag>, Map<String, Option<String>>, ()>> for MjBodyChild
Sourcefn from(v: MjImage) -> MjBodyChild
fn from(v: MjImage) -> MjBodyChild
Converts to this type from the input type.
Sourcefn from(v: MjNavbarLink) -> MjNavbarChild
fn from(v: MjNavbarLink) -> MjNavbarChild
Converts to this type from the input type.
Sourcefn from(v: MjNavbar) -> MjBodyChild
fn from(v: MjNavbar) -> MjBodyChild
Converts to this type from the input type.
Sourceimpl From<Component<PhantomData<MjPreviewTag>, (), OneOrMany<MjPreviewChild>>> for MjHeadChild
impl From<Component<PhantomData<MjPreviewTag>, (), OneOrMany<MjPreviewChild>>> for MjHeadChild
Sourcefn from(v: MjPreview) -> MjHeadChild
fn from(v: MjPreview) -> MjHeadChild
Converts to this type from the input type.
Sourceimpl From<Component<PhantomData<MjRawTag>, (), Vec<MjRawChild>>> for MjBodyChild
impl From<Component<PhantomData<MjRawTag>, (), Vec<MjRawChild>>> for MjBodyChild
Sourcefn from(v: MjRaw) -> MjBodyChild
fn from(v: MjRaw) -> MjBodyChild
Converts to this type from the input type.
Sourceimpl From<Component<PhantomData<MjRawTag>, (), Vec<MjRawChild>>> for MjHeadChild
impl From<Component<PhantomData<MjRawTag>, (), Vec<MjRawChild>>> for MjHeadChild
Sourcefn from(v: MjRaw) -> MjHeadChild
fn from(v: MjRaw) -> MjHeadChild
Converts to this type from the input type.
Sourceimpl From<Component<PhantomData<MjSectionTag>, Map<String, Option<String>>, Vec<MjBodyChild>>> for MjBodyChild
impl From<Component<PhantomData<MjSectionTag>, Map<String, Option<String>>, Vec<MjBodyChild>>> for MjBodyChild
Sourcefn from(v: MjSection) -> MjBodyChild
fn from(v: MjSection) -> MjBodyChild
Converts to this type from the input type.
Sourceimpl From<Component<PhantomData<MjSocialElementTag>, Map<String, Option<String>>, Vec<MjRawChild>>> for MjSocialChild
impl From<Component<PhantomData<MjSocialElementTag>, Map<String, Option<String>>, Vec<MjRawChild>>> for MjSocialChild
Sourcefn from(v: MjSocialElement) -> MjSocialChild
fn from(v: MjSocialElement) -> MjSocialChild
Converts to this type from the input type.
Sourceimpl From<Component<PhantomData<MjSocialTag>, Map<String, Option<String>>, Vec<MjSocialChild>>> for MjBodyChild
impl From<Component<PhantomData<MjSocialTag>, Map<String, Option<String>>, Vec<MjSocialChild>>> for MjBodyChild
Sourcefn from(v: MjSocial) -> MjBodyChild
fn from(v: MjSocial) -> MjBodyChild
Converts to this type from the input type.
Sourceimpl From<Component<PhantomData<MjSpacerTag>, Map<String, Option<String>>, ()>> for MjBodyChild
impl From<Component<PhantomData<MjSpacerTag>, Map<String, Option<String>>, ()>> for MjBodyChild
Sourcefn from(v: MjSpacer) -> MjBodyChild
fn from(v: MjSpacer) -> MjBodyChild
Converts to this type from the input type.
Sourceimpl From<Component<PhantomData<MjStyleTag>, MjStyleAttributes, String>> for MjHeadChild
impl From<Component<PhantomData<MjStyleTag>, MjStyleAttributes, String>> for MjHeadChild
Sourcefn from(v: MjStyle) -> MjHeadChild
fn from(v: MjStyle) -> MjHeadChild
Converts to this type from the input type.
Sourceimpl From<Component<PhantomData<MjTableTag>, Map<String, Option<String>>, Vec<MjBodyChild>>> for MjBodyChild
impl From<Component<PhantomData<MjTableTag>, Map<String, Option<String>>, Vec<MjBodyChild>>> for MjBodyChild
Sourcefn from(v: MjTable) -> MjBodyChild
fn from(v: MjTable) -> MjBodyChild
Converts to this type from the input type.
Sourceimpl From<Component<PhantomData<MjTextTag>, Map<String, Option<String>>, Vec<MjRawChild>>> for MjBodyChild
impl From<Component<PhantomData<MjTextTag>, Map<String, Option<String>>, Vec<MjRawChild>>> for MjBodyChild
Sourcefn from(v: MjText) -> MjBodyChild
fn from(v: MjText) -> MjBodyChild
Converts to this type from the input type.
Sourceimpl From<Component<PhantomData<MjTitleTag>, (), String>> for MjHeadChild
impl From<Component<PhantomData<MjTitleTag>, (), String>> for MjHeadChild
Sourcefn from(v: MjTitle) -> MjHeadChild
fn from(v: MjTitle) -> MjHeadChild
Converts to this type from the input type.
Sourceimpl From<Component<PhantomData<MjWrapperTag>, Map<String, Option<String>>, Vec<MjBodyChild>>> for MjBodyChild
impl From<Component<PhantomData<MjWrapperTag>, Map<String, Option<String>>, Vec<MjBodyChild>>> for MjBodyChild
Sourcefn from(v: MjWrapper) -> MjBodyChild
fn from(v: MjWrapper) -> MjBodyChild
Converts to this type from the input type.
Sourceimpl From<Component<String, Map<String, Option<String>>, Vec<MjBodyChild>>> for MjBodyChild
impl From<Component<String, Map<String, Option<String>>, Vec<MjBodyChild>>> for MjBodyChild
Sourcefn from(v: Node<MjBodyChild>) -> MjBodyChild
fn from(v: Node<MjBodyChild>) -> MjBodyChild
Converts to this type from the input type.
Sourceimpl From<Component<String, Map<String, Option<String>>, Vec<MjRawChild>>> for MjRawChild
impl From<Component<String, Map<String, Option<String>>, Vec<MjRawChild>>> for MjRawChild
Sourcefn from(v: Node<MjRawChild>) -> MjRawChild
fn from(v: Node<MjRawChild>) -> MjRawChild
Converts to this type from the input type.
Sourceimpl<Tag: PartialEq, Attributes: PartialEq, Children: PartialEq> PartialEq for Component<Tag, Attributes, Children>
impl<Tag: PartialEq, Attributes: PartialEq, Children: PartialEq> PartialEq for Component<Tag, Attributes, Children>
Sourceimpl<Tag: StaticTag, Attributes: JsonAttributes, Children: JsonChildren> Serialize for Component<PhantomData<Tag>, Attributes, Children>
impl<Tag: StaticTag, Attributes: JsonAttributes, Children: JsonChildren> Serialize for Component<PhantomData<Tag>, Attributes, Children>
Sourceimpl TryInto<Component<PhantomData<CommentTag>, (), String>> for MjAccordionChild
impl TryInto<Component<PhantomData<CommentTag>, (), String>> for MjAccordionChild
Sourceimpl TryInto<Component<PhantomData<CommentTag>, (), String>> for MjBodyChild
impl TryInto<Component<PhantomData<CommentTag>, (), String>> for MjBodyChild
Sourceimpl TryInto<Component<PhantomData<CommentTag>, (), String>> for MjCarouselChild
impl TryInto<Component<PhantomData<CommentTag>, (), String>> for MjCarouselChild
Sourceimpl TryInto<Component<PhantomData<CommentTag>, (), String>> for MjHeadChild
impl TryInto<Component<PhantomData<CommentTag>, (), String>> for MjHeadChild
Sourceimpl TryInto<Component<PhantomData<CommentTag>, (), String>> for MjRawChild
impl TryInto<Component<PhantomData<CommentTag>, (), String>> for MjRawChild
Sourceimpl TryInto<Component<PhantomData<CommentTag>, (), String>> for MjSocialChild
impl TryInto<Component<PhantomData<CommentTag>, (), String>> for MjSocialChild
Sourceimpl TryInto<Component<PhantomData<MjAccordionElementTag>, Map<String, Option<String>>, MjAccordionElementChildren>> for MjAccordionChild
impl TryInto<Component<PhantomData<MjAccordionElementTag>, Map<String, Option<String>>, MjAccordionElementChildren>> for MjAccordionChild
Sourceimpl TryInto<Component<PhantomData<MjAccordionTag>, Map<String, Option<String>>, Vec<MjAccordionChild>>> for MjBodyChild
impl TryInto<Component<PhantomData<MjAccordionTag>, Map<String, Option<String>>, Vec<MjAccordionChild>>> for MjBodyChild
Sourceimpl TryInto<Component<PhantomData<MjAttributesAllTag>, Map<String, Option<String>>, ()>> for MjAttributesChild
impl TryInto<Component<PhantomData<MjAttributesAllTag>, Map<String, Option<String>>, ()>> for MjAttributesChild
Sourceimpl TryInto<Component<PhantomData<MjAttributesClassTag>, MjAttributesClassAttributes, ()>> for MjAttributesChild
impl TryInto<Component<PhantomData<MjAttributesClassTag>, MjAttributesClassAttributes, ()>> for MjAttributesChild
Sourceimpl TryInto<Component<PhantomData<MjAttributesTag>, (), Vec<MjAttributesChild>>> for MjHeadChild
impl TryInto<Component<PhantomData<MjAttributesTag>, (), Vec<MjAttributesChild>>> for MjHeadChild
Sourceimpl TryInto<Component<PhantomData<MjBreakpointTag>, MjBreakpointAttributes, ()>> for MjHeadChild
impl TryInto<Component<PhantomData<MjBreakpointTag>, MjBreakpointAttributes, ()>> for MjHeadChild
Sourceimpl TryInto<Component<PhantomData<MjButtonTag>, Map<String, Option<String>>, Vec<MjBodyChild>>> for MjBodyChild
impl TryInto<Component<PhantomData<MjButtonTag>, Map<String, Option<String>>, Vec<MjBodyChild>>> for MjBodyChild
Sourceimpl TryInto<Component<PhantomData<MjCarouselImageTag>, Map<String, Option<String>>, ()>> for MjCarouselChild
impl TryInto<Component<PhantomData<MjCarouselImageTag>, Map<String, Option<String>>, ()>> for MjCarouselChild
Sourceimpl TryInto<Component<PhantomData<MjCarouselTag>, Map<String, Option<String>>, Vec<MjCarouselChild>>> for MjBodyChild
impl TryInto<Component<PhantomData<MjCarouselTag>, Map<String, Option<String>>, Vec<MjCarouselChild>>> for MjBodyChild
Sourceimpl TryInto<Component<PhantomData<MjColumnTag>, Map<String, Option<String>>, Vec<MjBodyChild>>> for MjBodyChild
impl TryInto<Component<PhantomData<MjColumnTag>, Map<String, Option<String>>, Vec<MjBodyChild>>> for MjBodyChild
Sourceimpl TryInto<Component<PhantomData<MjDividerTag>, Map<String, Option<String>>, ()>> for MjBodyChild
impl TryInto<Component<PhantomData<MjDividerTag>, Map<String, Option<String>>, ()>> for MjBodyChild
Sourceimpl TryInto<Component<PhantomData<MjFontTag>, MjFontAttributes, ()>> for MjHeadChild
impl TryInto<Component<PhantomData<MjFontTag>, MjFontAttributes, ()>> for MjHeadChild
Sourceimpl TryInto<Component<PhantomData<MjGroupTag>, Map<String, Option<String>>, Vec<MjBodyChild>>> for MjBodyChild
impl TryInto<Component<PhantomData<MjGroupTag>, Map<String, Option<String>>, Vec<MjBodyChild>>> for MjBodyChild
Sourceimpl TryInto<Component<PhantomData<MjHeroTag>, Map<String, Option<String>>, Vec<MjBodyChild>>> for MjBodyChild
impl TryInto<Component<PhantomData<MjHeroTag>, Map<String, Option<String>>, Vec<MjBodyChild>>> for MjBodyChild
Sourceimpl TryInto<Component<PhantomData<MjImageTag>, Map<String, Option<String>>, ()>> for MjBodyChild
impl TryInto<Component<PhantomData<MjImageTag>, Map<String, Option<String>>, ()>> for MjBodyChild
Sourceimpl TryInto<Component<PhantomData<MjPreviewTag>, (), OneOrMany<MjPreviewChild>>> for MjHeadChild
impl TryInto<Component<PhantomData<MjPreviewTag>, (), OneOrMany<MjPreviewChild>>> for MjHeadChild
Sourceimpl TryInto<Component<PhantomData<MjRawTag>, (), Vec<MjRawChild>>> for MjBodyChild
impl TryInto<Component<PhantomData<MjRawTag>, (), Vec<MjRawChild>>> for MjBodyChild
Sourceimpl TryInto<Component<PhantomData<MjRawTag>, (), Vec<MjRawChild>>> for MjHeadChild
impl TryInto<Component<PhantomData<MjRawTag>, (), Vec<MjRawChild>>> for MjHeadChild
Sourceimpl TryInto<Component<PhantomData<MjSectionTag>, Map<String, Option<String>>, Vec<MjBodyChild>>> for MjBodyChild
impl TryInto<Component<PhantomData<MjSectionTag>, Map<String, Option<String>>, Vec<MjBodyChild>>> for MjBodyChild
Sourceimpl TryInto<Component<PhantomData<MjSocialElementTag>, Map<String, Option<String>>, Vec<MjRawChild>>> for MjSocialChild
impl TryInto<Component<PhantomData<MjSocialElementTag>, Map<String, Option<String>>, Vec<MjRawChild>>> for MjSocialChild
Sourceimpl TryInto<Component<PhantomData<MjSocialTag>, Map<String, Option<String>>, Vec<MjSocialChild>>> for MjBodyChild
impl TryInto<Component<PhantomData<MjSocialTag>, Map<String, Option<String>>, Vec<MjSocialChild>>> for MjBodyChild
Sourceimpl TryInto<Component<PhantomData<MjSpacerTag>, Map<String, Option<String>>, ()>> for MjBodyChild
impl TryInto<Component<PhantomData<MjSpacerTag>, Map<String, Option<String>>, ()>> for MjBodyChild
Sourceimpl TryInto<Component<PhantomData<MjStyleTag>, MjStyleAttributes, String>> for MjHeadChild
impl TryInto<Component<PhantomData<MjStyleTag>, MjStyleAttributes, String>> for MjHeadChild
Sourceimpl TryInto<Component<PhantomData<MjTableTag>, Map<String, Option<String>>, Vec<MjBodyChild>>> for MjBodyChild
impl TryInto<Component<PhantomData<MjTableTag>, Map<String, Option<String>>, Vec<MjBodyChild>>> for MjBodyChild
Sourceimpl TryInto<Component<PhantomData<MjTextTag>, Map<String, Option<String>>, Vec<MjRawChild>>> for MjBodyChild
impl TryInto<Component<PhantomData<MjTextTag>, Map<String, Option<String>>, Vec<MjRawChild>>> for MjBodyChild
Sourceimpl TryInto<Component<PhantomData<MjTitleTag>, (), String>> for MjHeadChild
impl TryInto<Component<PhantomData<MjTitleTag>, (), String>> for MjHeadChild
Sourceimpl TryInto<Component<PhantomData<MjWrapperTag>, Map<String, Option<String>>, Vec<MjBodyChild>>> for MjBodyChild
impl TryInto<Component<PhantomData<MjWrapperTag>, Map<String, Option<String>>, Vec<MjBodyChild>>> for MjBodyChild
Sourceimpl TryInto<Component<String, Map<String, Option<String>>, Vec<MjBodyChild>>> for MjBodyChild
impl TryInto<Component<String, Map<String, Option<String>>, Vec<MjBodyChild>>> for MjBodyChild
impl<Tag: Eq, Attributes: Eq, Children: Eq> Eq for Component<Tag, Attributes, Children>
impl<Tag, Attributes, Children> StructuralPartialEq for Component<Tag, Attributes, Children>